@@ -1,8 +1,5 @@
 import random
 
-def print(text):
-    return text
-
 chars = "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ123456!£$%^&*(`)"
 
 def gen_password(password_len, password_count):
@@ -11,4 +8,4 @@ def gen_password(password_len, password_count):
             for x in range(0,password_len):
                 password_char = random.choice(chars)
                 password      = password + password_char
-            print(password) 
+                yield password 
